ete2.phylomedb.phylomeDB

Package ete2 :: Package phylomedb :: Module phylomeDB |
[hide private]
[frames] | no frames]

# Module phylomeDB

source code

Classes | [hide private]
| PhylomeDBConnector Reuturns a connector to a phylomeDB database.

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev90``'`` 'phylomedb' provides an access API to the data stored in the phylogenetic database PhylomeDB *[1].
| ROOTED_PHYLOMES = ``{`1`:` `{``'``Aga``'``:` 8`,` `'``Ago``'``:` 9`,` `'``Ame``'``:` 8`,` `'``Ath``'``:` 10`...``
| __package__ = ``'``ete2.phylomedb``'``

Variables Details | [hide private]

### __VERSION__
    'phylomedb' provides an access API to the data stored in the
    phylogenetic database PhylomeDB *[1].

    All methods to perform queries are implemented within the
    PhylomeDBConnector class.

     *[1] PhylomeDB: a database for genome-wide collections of gene
     phylogenies Jaime Huerta-Cepas, Anibal Bueno, Joaquin Dopazo and Toni
     Gabaldon.

          PhylomeDB is a database of complete phylomes derived for
          different genomes within a specific taxonomic range. All
          phylomes in the database are built using a high-quality
          phylogenetic pipeline that includes evolutionary model testing
          and alignment trimming phases. For each genome, PhylomeDB
          provides the alignments, phylogentic trees and tree-based
          orthology predictions for every single encoded protein.
  Value:
      'ete2-2.0rev90'

  ### ROOTED_PHYLOMES Value:
      {1: {'Aga': 8,
           'Ago': 9,
           'Ame': 8,
           'Ath': 10,
           'Bta': 3,
           'Cal': 9,
           'Cbr': 8,
           'Cel': 8,
      ...